@@ -16,7 +16,6 @@
 #    under the License.
 
 import errno
-import logging
 import os
 import shutil
 
@@ -24,6 +23,7 @@ from oslo.serialization import jsonutils
 import six
 
 from taskflow import exceptions as exc
+from taskflow import logging
 from taskflow.persistence.backends import base
 from taskflow.persistence import logbook
 from taskflow.utils import lock_utils
