@@ -14,7 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import threading
 import time
 
 from concurrent import futures
@@ -22,17 +21,19 @@ from oslo.utils import timeutils
 
 from taskflow.engines.worker_based import executor
 from taskflow.engines.worker_based import protocol as pr
+from taskflow import task as task_atom
 from taskflow import test
 from taskflow.test import mock
-from taskflow.tests import utils
-from taskflow.utils import misc
+from taskflow.tests import utils as test_utils
+from taskflow.types import failure
+from taskflow.utils import threading_utils
 
 
 class TestWorkerTaskExecutor(test.MockTestCase):
 
     def setUp(self):
         super(TestWorkerTaskExecutor, self).setUp()
-        self.task = utils.DummyTask()
+        self.task = test_utils.DummyTask()
         self.task_uuid = 'task-uuid'
         self.task_args = {'a': 'a'}
         self.task_result = 'task-result'
@@ -42,7 +43,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         self.executor_uuid = 'executor-uuid'
         self.executor_exchange = 'executor-exchange'
         self.executor_topic = 'test-topic1'
-        self.proxy_started_event = threading.Event()
+        self.proxy_started_event = threading_utils.Event()
 
         # patch classes
         self.proxy_mock, self.proxy_inst_mock = self.patchClass(
@@ -57,7 +58,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         self.request_inst_mock.expired = False
         self.request_inst_mock.task_cls = self.task.name
         self.wait_for_any_mock = self.patch(
-            'taskflow.engines.worker_based.executor.async_utils.wait_for_any')
+            'taskflow.engines.action_engine.executor.async_utils.wait_for_any')
         self.message_mock = mock.MagicMock(name='message')
         self.message_mock.properties = {'correlation_id': self.task_uuid,
                                         'type': pr.RESPONSE}
@@ -102,17 +103,22 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         self.assertEqual(expected_calls, self.request_inst_mock.mock_calls)
 
     def test_on_message_response_state_progress(self):
-        response = pr.Response(pr.PROGRESS, progress=1.0)
+        response = pr.Response(pr.EVENT,
+                               event_type=task_atom.EVENT_UPDATE_PROGRESS,
+                               details={'progress': 1.0})
         ex = self.executor()
         ex._requests_cache[self.task_uuid] = self.request_inst_mock
         ex._process_response(response.to_dict(), self.message_mock)
 
-        self.assertEqual(self.request_inst_mock.mock_calls,
-                         [mock.call.on_progress(progress=1.0)])
+        expected_calls = [
+            mock.call.notifier.notify(task_atom.EVENT_UPDATE_PROGRESS,
+                                      {'progress': 1.0}),
+        ]
+        self.assertEqual(expected_calls, self.request_inst_mock.mock_calls)
 
     def test_on_message_response_state_failure(self):
-        failure = misc.Failure.from_exception(Exception('test'))
-        failure_dict = failure.to_dict()
+        a_failure = failure.Failure.from_exception(Exception('test'))
+        failure_dict = a_failure.to_dict()
         response = pr.Response(pr.FAILURE, result=failure_dict)
         ex = self.executor()
         ex._requests_cache[self.task_uuid] = self.request_inst_mock
@@ -121,7 +127,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         self.assertEqual(len(ex._requests_cache), 0)
         expected_calls = [
             mock.call.transition_and_log_error(pr.FAILURE, logger=mock.ANY),
-            mock.call.set_result(result=utils.FailureMatcher(failure))
+            mock.call.set_result(result=test_utils.FailureMatcher(a_failure))
         ]
         self.assertEqual(expected_calls, self.request_inst_mock.mock_calls)
 
@@ -211,11 +217,11 @@ class TestWorkerTaskExecutor(test.MockTestCase):
 
         expected_calls = [
             mock.call.Request(self.task, self.task_uuid, 'execute',
-                              self.task_args, None, self.timeout),
+                              self.task_args, self.timeout),
             mock.call.request.transition_and_log_error(pr.PENDING,
                                                        logger=mock.ANY),
-            mock.call.proxy.publish(msg=self.request_inst_mock,
-                                    routing_key=self.executor_topic,
+            mock.call.proxy.publish(self.request_inst_mock,
+                                    self.executor_topic,
                                     reply_to=self.executor_uuid,
                                     correlation_id=self.task_uuid)
         ]
@@ -231,13 +237,13 @@ class TestWorkerTaskExecutor(test.MockTestCase):
 
         expected_calls = [
             mock.call.Request(self.task, self.task_uuid, 'revert',
-                              self.task_args, None, self.timeout,
+                              self.task_args, self.timeout,
                               failures=self.task_failures,
                               result=self.task_result),
             mock.call.request.transition_and_log_error(pr.PENDING,
                                                        logger=mock.ANY),
-            mock.call.proxy.publish(msg=self.request_inst_mock,
-                                    routing_key=self.executor_topic,
+            mock.call.proxy.publish(self.request_inst_mock,
+                                    self.executor_topic,
                                     reply_to=self.executor_uuid,
                                     correlation_id=self.task_uuid)
         ]
@@ -250,7 +256,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
 
         expected_calls = [
             mock.call.Request(self.task, self.task_uuid, 'execute',
-                              self.task_args, None, self.timeout)
+                              self.task_args, self.timeout),
         ]
         self.assertEqual(self.master_mock.mock_calls, expected_calls)
 
@@ -264,11 +270,11 @@ class TestWorkerTaskExecutor(test.MockTestCase):
 
         expected_calls = [
             mock.call.Request(self.task, self.task_uuid, 'execute',
-                              self.task_args, None, self.timeout),
+                              self.task_args, self.timeout),
             mock.call.request.transition_and_log_error(pr.PENDING,
                                                        logger=mock.ANY),
-            mock.call.proxy.publish(msg=self.request_inst_mock,
-                                    routing_key=self.executor_topic,
+            mock.call.proxy.publish(self.request_inst_mock,
+                                    self.executor_topic,
                                     reply_to=self.executor_uuid,
                                     correlation_id=self.task_uuid),
             mock.call.request.transition_and_log_error(pr.FAILURE,
@@ -283,7 +289,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         ex.wait_for_any(fs)
 
         expected_calls = [
-            mock.call(fs, None)
+            mock.call(fs, timeout=None)
         ]
         self.assertEqual(self.wait_for_any_mock.mock_calls, expected_calls)
 
@@ -294,7 +300,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         ex.wait_for_any(fs, timeout)
 
         master_mock_calls = [
-            mock.call(fs, timeout)
+            mock.call(fs, timeout=timeout)
         ]
         self.assertEqual(self.wait_for_any_mock.mock_calls, master_mock_calls)
 
@@ -303,7 +309,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         ex.start()
 
         # make sure proxy thread started
-        self.proxy_started_event.wait()
+        self.assertTrue(self.proxy_started_event.wait(test_utils.WAIT_TIMEOUT))
 
         # stop executor
         ex.stop()
@@ -319,7 +325,7 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         ex.start()
 
         # make sure proxy thread started
-        self.proxy_started_event.wait()
+        self.assertTrue(self.proxy_started_event.wait(test_utils.WAIT_TIMEOUT))
 
         # start executor again
         ex.start()
@@ -362,14 +368,14 @@ class TestWorkerTaskExecutor(test.MockTestCase):
         ex.start()
 
         # make sure thread started
-        self.proxy_started_event.wait()
+        self.assertTrue(self.proxy_started_event.wait(test_utils.WAIT_TIMEOUT))
 
         # restart executor
         ex.stop()
         ex.start()
 
         # make sure thread started
-        self.proxy_started_event.wait()
+        self.assertTrue(self.proxy_started_event.wait(test_utils.WAIT_TIMEOUT))
 
         # stop executor
         ex.stop()
